#!/bin/sh
################################################################################
## Program name : undeployWKC.sh
## Purpose: This module will undeploy WKC Lite and Pro services including deployment, PV and PVC
###############################################################################
## IBM Confidential
## OCO Source Materials
## 5724-Q36
## Copyright IBM Corp. 2016, 2017, 2018, 2019, 2020
###############################################################################

set -e
echo "Executing cleanupWKC.sh" > /tmp/cleanupWKC.log 2>&1

#file="$ishome/ASBServer/bin/iisAdmin.shshome/ASBServer/bin/iisAdmin.sh""

usage()
{
  echo "USAGE: $0 <MS tier host name with fqdn> $1 <MS tier host OS user> $2 <IIS_HOME dir path>"
#  echo "USAGE: $1 <MS tier host OS user>"
#  echo "USAGE: $2 <IIS_HOME dir path>"
  exit -1
}

masterHost=$1
masterUser=$2
ishome=$3

file="$ishome/ASBServer/bin/iisAdmin.sh"
setLocalVariables()
{
  basedir=$(dirname `which $0`)
  if [[ ! -f "${file}" ]]; then
    echo "File $file does not exist"
    exit 1
  fi
  echo "masterHost: $1"
  echo "masterUser: $2"
  echo "ishome: $3"  
}

checkWKCkeys()
{
 echo "Checking IISADMIN WKC keys ...."
 wkcicon=$($file -d -key com.ibm.iis.launchpad.application.wkc.icon)
 echo "com.ibm.iis.launchpad.application.wkc.icon is: $wkcicon"
 wkcname=$($file -d -key com.ibm.iis.launchpad.application.wkc.name)
 echo "com.ibm.iis.launchpad.application.wkc.name is: $wkcname"
 if [[ -z $wkcicon && -z $wkcname ]]; then
  echo "IISADMIN properties are not set for WKC "
#  exit 1
 else
  echo "IISADMIN properties are set for WKC. Proceeding with undeployment process..."
 fi
}

undeployWKC()
{
TARGET_LOCATION=${masterUser}@${masterHost}:/tmp
scp ${basedir}/undeployWKC.sh ${basedir}/wkcimages*.txt ${TARGET_LOCATION}
#scp ${basedir}/wkcimageslite.txt ${TARGET_LOCATION}
#scp ${basedir}/wkcimagespro.txt ${TARGET_LOCATION}

ssh -o StrictHostKeyChecking=no -tT  ${masterUser}@${masterHost} <<'ENDSSH'
#commands to run on remote host
	
chmod +x /tmp/undeployWKC.sh

cd /tmp
./undeployWKC.sh
ug_rtc=$?
if [[ $ug_rtc -ne 0 ]] ; then
   exit $ug_rtc
  
fi
ENDSSH
#scp root@hk-wkc1-node.fyre.ibm.com:undeployWKC.sh /tmp/
}

unsetWKCProperties()
{
  echo "Unset IISADMIN WKC properties........ "
  $file -unset -key com.ibm.iis.wkc.lite.deploy.flag
  $file -unset -key com.ibm.iis.launchpad.application.wkc.url
  $file -unset -key com.ibm.iis.launchpad.application.wkc.icon
  $file -unset -key com.ibm.iis.launchpad.application.wkc.name
  $file -unset -key com.ibm.iis.wkc.pro.deploy.flag
  echo "IISADMIN WKC properties were successfully unset !! "
}
postCheckWKCkeys()
{
 echo "Checking IISADMIN WKC keys after undeployment...."
 wkcicon=$($file -d -key com.ibm.iis.launchpad.application.wkc.icon)
 echo "com.ibm.iis.launchpad.application.wkc.icon is: $wkcicon"
 wkcname=$($file -d -key com.ibm.iis.launchpad.application.wkc.name)
 echo "com.ibm.iis.launchpad.application.wkc.name is: $wkcname"
 if [[ -z $wkcicon && -z $wkcname ]]; then
  echo "WKC IISADMIN properties are successfully unset !!"
  echo " "
  echo " "
  echo "Watson Knowledge Catalog undeployment is successful on both MS tier and IIS Services Hosts!!"
 else
  echo "Failed to unset WKC IISADMIN properties..."
 fi
}

deleteWKCProLicenseFile()
{
  echo "Deleting WKC Pro License file!!"
  if [[ -f "$ishome/iso-swid/ibm.com_IBM_Watson_Knowledge_Catalog_Professional_on-prem-11.7.1.swidtag" ]]; then
   
    sudo rm -rf "$ishome/iso-swid/ibm.com_IBM_Watson_Knowledge_Catalog_Professional_on-prem-11.7.1.swidtag"
    echo "Deleted License file $ishome/iso-swid/ibm.com_IBM_Watson_Knowledge_Catalog_Professional_on-prem-11.7.1.swidtag !!"  
  else
    echo "Could not delete license file $ishome/iso-swid/ibm.com_IBM_Watson_Knowledge_Catalog_Professional_on-prem-11.7.1.swidtag !!"
  fi

}

############################
###     MAIN Program :
############################


if [[ $# < 3 ]] ; then
   usage
fi

echo "$(date -u "+%Y-%m-%d %H:%M:%S.%M3 UTC")"
echo "##########################################"
echo "#####WARNING WARNING WARNING WARNING######"
echo "Proceeding with this script will permanently remove the following"
echo "WKC Lite/Pro Deployment"
echo "WKC Lite/Pro Docker images"
echo "Unset IISADMIN WKC properties"
if [[ $# -ne 2 || $2 -ne 1 ]]; then
echo "Would you like to proceed? Enter number 1 or 2 for choices Yes or No"
select Proceed in "Yes" "No"; do
  case $Proceed in
  Yes) echo "Now proceeding with clean" ; break;;
  No)  echo "Not proceeding" ; exit;;
 esac
done
fi



setLocalVariables
checkWKCkeys
undeployWKC
unsetWKCProperties
postCheckWKCkeys
deleteWKCProLicenseFile
