#!/bin/sh
################################################################################
## Program name : undeployWKC.sh
## Purpose: This module will undeploy WKC Lite and Pro services including deployment, PV and PVC
###############################################################################
## IBM Confidential
## OCO Source Materials
## 5724-Q36
## Copyright IBM Corp. 2016, 2017, 2018, 2019, 2020
###############################################################################

#set -e
echo "Executing undeployWKC.sh" > /tmp/undeployWKC.log 2>&1

setLocalVariables()
{
  basedir=$(dirname `which $0`)
  timeStamp=`date -u "+%Y-%m-%d_%H:%M:%S.%M3"`

  undeploywkclog="${basedir}/undeploywkc_${timeStamp}.log"
  error=0
  warning=0
  info=0
  status=0  
}

createlogFile(){
	
	echo "$(date -u "+%Y-%m-%d %H:%M:%S.%M3 UTC") --${INST_TYPE} WKC undeployment log" >> ${undeploywkclog}
	
}
logError()
{
   echo "FAIL: ${1}"
   echo "$(date -u "+%Y-%m-%d %H:%M:%S.%M3 UTC") -- FAIL: ${1}" >> ${undeploywkclog}
   error=1
}


logSuccess()
{
   echo "PASS: ${1}"
   echo "$(date -u "+%Y-%m-%d %H:%M:%S.%M3 UTC") -- PASS: ${1}" >> ${undeploywkclog}
   success=1
}

logInfo()
{
   echo "${1}"
   echo "$(date -u "+%Y-%m-%d %H:%M:%S.%M3 UTC") -- INFO >>>>>>>> : ${1}" >> ${undeploywkclog}
   info=1
}

logWarning()
{
   echo "$(date -u "+%Y-%m-%d %H:%M:%S.%M3 UTC") -- WARNING >>>>>>>> : ${1}" >> ${undeploywkclog}
   warn=1
}
logDetails()
{
   echo "${1}" >> ${undeploywkclog}
   warn=1
}


checkHelm()
{

logInfo "CHECKNG HELM INSTALLED VERSION..."
helmver=$(helm version)
logInfo "${helmver}"

#Check HELM client version is running
 helmclnver=$(helm version | grep Client:)
 if [[ ! -z ${helmclnver} && "${helmclnver}" == *"SemVer:"* && "${helmclnver}" == *"GitCommit:"* && "${helmclnver}" == *"GitTreeState:"* ]]; then
  logInfo "Helm client is running..."
 else
  logError "Helm client is not running..Abort execution!!"
  exit 1
 fi

#Check HELM Server version is running
helmserver=$(helm version | grep Server:)
 if [[ ! -z ${helmserver} && "${helmserver}" == *"SemVer:"* && "${helmserver}" == *"GitCommit:"* && "${helmserver}" == *"GitTreeState:"* ]]; then
  logInfo "Helm server is running..."
 else
  logError "Helm server is not running..Abort execution!!"
  exit 1
 fi

}

getSnapshot(){
status=0
logInfo "GET MS TIER DEPLOYMENT SNAPSHOT.................................."

logInfo " "
logInfo "Show MS tier deployments........................................."
msdeployments=$(kubectl get deployments --all-namespaces)
logInfo "$msdeployments"

logInfo " "
logInfo "Show MS tier pods status........................................."
mspods=$(kubectl get pods --all-namespaces)
logInfo "$mspods"

logInfo " "
logInfo "Show MS tier PVCs................................................"
mspvc=$(kubectl get pvc --all-namespaces)
logInfo "$mspvc"

logInfo " "
logInfo "Show MS tier PVs................................................."
mspv=$(kubectl get pv --all-namespaces)
logInfo "$mspv"

logInfo " "
logInfo " "

logInfo "GET THE SNAPSHOT OF WKC DEPLOYMENT............."
logInfo " "
logInfo "   Show deployed helm charts.........................................."
wkclist=$(helm list | awk '{print $1}'| grep -Ev NAME)
logInfo "     List of deployed WKC services: $wkclist"
if [[ ! -z "$wkclist" ]]; then
  status=1
fi

logInfo " "
logInfo "Show WKC pods status........................................."
wkcpods=$(kubectl get pods -n wkc)
logInfo "${wkcpods}"

logInfo " "
logInfo "   Show PVC informaton................................................"
wkcpvclist=$(kubectl get pvc -n wkc | awk '{print $1}'| grep -Ev NAME)
logInfo "      List of WKC PVCs: $wkcpvclist"
if [[ ! -z "$wkcpvclist" ]]; then
  status=1
fi

logInfo " "
logInfo "   Show PVs information................................................"
wkcpvlist=$(kubectl get pv | grep wkc/ | awk '{print $1}'| grep -Ev NAME)
logInfo "      List of WKC PVs: $wkcpvlist"

if [[ ! -z "$wkcpvlist" ]]; then
  status=1
fi

logInfo " "
logInfo "   Show tiller information............................................."
tillerstat=$(kubectl get deployments -n kube-system | grep tiller)
logInfo "${tillerstat}"
if [[ ! -z "$tillerstat" ]]; then
  status=1
fi

logInfo " "
logInfo "   Show tiller pod status.............................................."
tillerpod=$(kubectl get pods -n kube-system | grep tiller)
logInfo "${tillerpod}"
if [[ ! -z "$tillerpod" ]]; then
  status=1
fi

logInfo " "
logInfo "   Show WKC Lite docker images........................................."
wkcliteimages=$(cat "${basedir}/wkcimageslite.txt")
for liteimage in $wkcliteimages; do
imagename=`echo $liteimage | sed 's/:.*//'`
delimage=$(docker images | grep $imagename | awk '{print $1}')
if [[ ! -z "$delimage" ]]; then
logInfo "$delimage"
status=1
fi
done

logInfo " "
logInfo "   Show WKC Pro docker images.........................................."

wkcproimages=$(cat "${basedir}/wkcimagespro.txt")
#echo "$wkcproimages"
for proimage in $wkcproimages; do
imagename=`echo $proimage | sed 's/:.*//'`
delimage=$(docker images | grep $imagename | awk '{print $1}')
if [[ ! -z "$delimage" ]]; then
logInfo "$delimage"
status=1
fi
done
logInfo " "
logInfo "Check WKC PV storage directories........................................"
wkcpvdirlist="asset_file_api postgresql cloudant db2 rabbitmq"

for wkcpvdir in $wkcpvdirlist; do
if [[ -d $pvdir/$wkcpvdir ]]; then
  logInfo "WKC PV directory $pvdir/$wkcpvdir exist!!"
  status=1
fi
done

logInfo " "
logInfo "END OF THE WKC DEPLOYMENT SNAPSHOT............."
}


undeploy(){

logInfo " "
logInfo " "
logInfo "INITIATING WKC UNDEPLOYMENT PROCESS...................."
logInfo " "

logInfo "Undeploy Helm charts............."
wkclist=$(helm list | grep 'wkc-base\|wkc-base-pre\|wkc-base2\|ws-base\|wkc-pro-prereqs\|wkc-pro' | awk '{print $1}'| grep -Ev NAME)

for wkcitem in ${wkclist}; do
 helmdel=$(helm delete --purge $wkcitem)

logInfo "$helmdel"
done
logInfo " "
logInfo "Remove WKC PVCs................."
wkcpvclist=$(kubectl get pvc -n wkc | awk '{print $1}'| grep -Ev NAME)

for wkcpvc in ${wkcpvclist}; do
wkcpvcprotection=$(kubectl describe pvc $wkcpvc -n wkc | grep Finalizers)
#logInfo "$wkcpvc is protected: $wkcpvcprotection" 
remprot=$(kubectl patch pvc $wkcpvc -n wkc -p '{"metadata":{"finalizers":null}}')
#logInfo "Removed protection for PVC: '$wkcpvc' and safe to delete"
delpvc=$(kubectl delete pvc $wkcpvc -n wkc)
logInfo "PVC '$wkcpvc' has been deleted"

done

logInfo " "
logInfo "Remove WKC PVs................."
wkcpvlist=$(kubectl get pv | grep wkc/ | awk '{print $1}'| grep -Ev NAME)
#logInfo "List of WKC PVs: $wkcpvlist"

for wkcpv in ${wkcpvlist}; do
wkcpvprotection=$(kubectl describe pv $wkcpv | grep Finalizers)
#logInfo "$wkcpv is protected: $wkcpvprotection"
rempvprot=$(kubectl patch pv $wkcpv -p '{"metadata":{"finalizers":null}}')
#logInfo "Removed protection for PV: '$wkcpv' and safe to delete"
delpv=$(kubectl delete pv $wkcpv)
logInfo "$delpv"
done

logInfo " "
logInfo "Delete Tiller deployment................."

#Remove tiller deployment
tillername=$(kubectl get deployments -n kube-system | grep tiller | awk '{print $1}')
deltiller=$(kubectl delete deployment $tillername -n kube-system)
logInfo "$deltiller"

logInfo " "
logInfo "Delete WKC docker images................."
logInfo " "
#Remove WKC Lite  docker images
wkcliteimages=$(cat "${basedir}/wkcimageslite.txt")
for liteimage in $wkcliteimages; do
imagename=`echo $liteimage | sed 's/:.*//'`
#logInfo "WKC Lite docker image: $imagename"
delimage=$(docker images | grep $imagename | awk '{print $3}' | sort -u)
if [[ ! -z ${delimage} ]]; then
remimage=$(docker rmi $delimage -f)
logInfo "$imagename: -- "
logInfo " $remimage"
sleep 3
fi
done

#Remove WKC Pro docker images

wkcproimages=$(cat "${basedir}/wkcimagespro.txt")
for proimage in $wkcproimages; do
imagename=`echo $proimage | sed 's/:.*//'`
#logInfo "WKC Pro docker image: $imagename"
delimage=$(docker images | grep $imagename | awk '{print $3}' | sort -u)
if [[ ! -z ${delimage} ]]; then
remimage=$(docker rmi $delimage -f)
logInfo "$imagename: -- "
logInfo " $remimage"
sleep 3
fi
done

#Delete WKC pod by name wkc-pro-post-install-xxxxxx
logInfo " "
logInfo "Deleting WKC pro post instal pod.........."
wkcpostpod=$(kubectl get pods -n wkc | grep wkc-pro-post-install | awk '{print $1}')
if [[ ! -z ${wkcpostpod} ]]; then
delwkcpostpod=$(kubectl delete pod ${wkcpostpod} -n wkc)
logInfo "${delwkcpostpod}"
fi
}

getPVDir()
{
zookeeper_pv=$(kubectl get pv | grep zookeeper | awk '{print $1}')
zookeeper_pv=$(echo $zookeeper_pv | awk '{print $1}')
pvdir=$(kubectl describe pv $zookeeper_pv | grep 'Path:' | cut -d ":" -f 2 | sed 's|\(.*\)/.*|\1|' | sed 's/ //g')
}

deletePVFolders()
{
logInfo " "
logInfo "Delete WKC PV storage directories................."

wkcpvdirlist="asset_file_api postgresql cloudant db2 rabbitmq"

for wkcpvdir in $wkcpvdirlist; do
if [[ -d $pvdir/$wkcpvdir ]]; then
   rm -rf $pvdir/$wkcpvdir
  logInfo "Deleted WKC PV directory $pvdir/$wkcpvdir"
fi
done

}

removeHelm()
{
  logInfo " "
  logInfo "Remove helm folder /usr/local/bin/helm"
  sudo rm -rf /usr/local/bin/helm
}

setLocalVariables
createlogFile
checkHelm
getPVDir
getSnapshot
undeploy
deletePVFolders
getSnapshot
removeHelm

logInfo " "
logInfo "MS Tier execution status code: $status"

if [ $status -eq 0 ] ; then
logInfo "SUCCESSFULLY UNDEPLOYED WKC ON MS TIER HOST!! "
else
logInfo "WKC undeployment was not successful. Check the log file for details"
fi

